#
# spec file for package python-pyodbc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyodbc
Version:        4.0.30
Release:        bp153.1.17
Summary:        Python ODBC API
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/mkleehammer/pyodbc
Source:         https://files.pythonhosted.org/packages/source/p/pyodbc/pyodbc-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildRequires:  sqliteodbc
BuildRequires:  unixODBC-devel
%python_subpackages

%description
pyodbc is a Python 2.x and 3.x module that allows you to use ODBC
to connect to almost any database.

It implements the Python Database API Specification v2.0, but
additional features have been added to simplify database programming
even more.

%prep
%setup -q -n pyodbc-%{version}
mv tests2 tests-%{python2_bin_suffix}
mv tests3 tests-%{python3_bin_suffix}

%build
%python_build

%install
%python_install

%check
export PYTHONDONTWRITEBYTECODE=1
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python tests-%{$python_bin_suffix}/sqlitetests.py -v "Driver=SQLITE3;Database=sqlite.db"
}

%files %{python_files}
%{python_sitearch}/*
%license LICENSE.txt
%doc README.md

%changelog
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 4.0.30
  * Very large integers and non-numeric floats as parameters
* Wed Dec 25 2019 Dirk Hartmann <monex@liquid-co.de>
- Update to version 4.0.28
  * Fix incorrect size calcation for Unicode characters (#654)
  * Fix binding of 32-bit ints on 64-bit Linux (#611)
  * Fixes type mismatch for null/None with table value parameters. #596
  * Fixes and cleanup of unit tests for MS Access (#606), MySQL (#630 #632) and new tests (#637 #645)
* Sat Sep 14 2019 John Vandenberg <jayvdb@gmail.com>
- Use %%python_expand in %%check to allow building only a single
  flavour
* Mon Aug  5 2019 Dirk Hartmann <monex@liquid-co.de>
- Update to version 4.0.27:
  * Use int instead of bigint when possible (based on size of data)
    to work with drivers that don't support bigint at all.
  * Support SQL Server datetime2 precision. Previously more data
    was passed than the column precision causing an error.
  * Make Informix unit tests work again.
  * Correct encoding error on big-endian machines for connection
    errors. Default to native UTF16 instead of UTF16-LE.
  * Fix MySQL unit tests.
* Sun Mar 10 2019 Dirk Hartmann <monex@liquid-co.de>
- Update to version 4.0.26:
  * Issue #506 uncovered a potentially serious error where
    Unicode strings may not get a NULL terminator when being converted.
  * Issue #504 was a double decref in the error return path of executemany.
* Wed Jan 30 2019 Dirk Hartmann <monex@liquid-co.de>
- Update to version 4.0.25:
  * support for SQL Server Table-Valued Paramaters has arrived. See test_tvp in the SQL Server unit tests.
  * Support for IBM DB/2 DECFLOAT type (#472) by @c-dy
  * Better SQL Server and FreeTDS tests with known driver issues (#469) by @gordthompson.
  * Fix "function sequence error" with fast executemany (#450) by @v-makouz.
* Sat Aug 25 2018 jengelh@inai.de
- Strip filler wording from description.
* Wed Aug 22 2018 tchvatal@suse.com
- Really use upstream tarball
* Wed Aug 22 2018 tchvatal@suse.com
- Do not copy around but use PYTHONPATH to find the module
* Sun Aug 19 2018 monex@liquid-co.de
- Update to 4.0.24
* Thu Aug  9 2018 monex@liquid-co.de
- Added test cases for sqlite to check section.
  Unfortunaly the test cases are broken at the moment
  a bug report was created at github.
* Sun Aug  5 2018 monex@liquid-co.de
- Added LICENSE.txt and README.md to files.
- Use only one BuildRequires per line.
- Corrected wrong Release version.
* Sat Aug  4 2018 monex@liquid-co.de
- Corrected source url.
- Added sources again.
- Fix Url to upstream project.
* Sat Aug  4 2018 monex@liquid-co.de
- Remove unneeded source because it is fetched automatically.
* Fri Aug  3 2018 2monex@gmx.net
- Use URL as source according to python packaginf guidelines.
* Fri Aug  3 2018 nrochard@gmail.com
- Update to version 4.0.23
* Thu Jun 28 2018 monex@liquid-co.de
- Use python single spec.
* Mon Feb 27 2017 monex@liquid-co.de
-Update to version 4.0.13
* Sat May  2 2015 monex@liquid-co.de
- added missing source file
* Sat May  2 2015 monex@liquid-co.de
- updated to version 3.0.10
* Sun Aug  4 2013 monex@liquid-co.de
- updated to version 3.0.7
  * Added context manager support to Cursor
  * Added padding for driver bugs writing an extra byte
  * Cursor.executemany now accepts an iterator or generator.
  * Compilation improvements for FreeBSD, Cygwin, and OS/X
  * Use SQL_DATA_AT_EXEC instead of SQL_DATA_LEN_AT_EXEC when possible for driver compatibility.
  * Row objects can now be pickled.
* Fri Nov 16 2012 2monex@gmx.net
- change source file compression
* Fri Nov 16 2012 2monex@gmx.net
- updated to version 3.0.6
  * Fixed building on Python 2.5. Other versions are not affected.
  * Fixed "function sequence" errors caused by prepared SQL not being cleared ("unprepared")
  when a catalog function is executed.
  * Added Cursor.commit() and Cursor.rollback(). It is now possible to use only a cursor in
  your code instead of keeping track of a connection and a cursor.
  * Added readonly keyword to connect. If set to True, SQLSetConnectAttr
  SQL_ATTR_ACCESS_MODE is set to SQL_MODE_READ_ONLY.
  This may provide better locking semantics or speed for some drivers.
  * Fixed an error reading SQL Server XML data types longer than 4K.
* Mon Jun  4 2012 monex@liquid-co.de
- removed unneded requires
* Mon Jun  4 2012 monex@liquid-co.de
- initial version
